Changelog
=========

Here you can see the full list of changes between each releases of Cfg-Loader.

Version 0.3.0
-------------

Unreleased

Version 0.2.3
-------------

Released on August 13th 2018

Chore

- Update marshmallow dependencies

Version 0.2.2
-------------

Released on July 27th 2018

Version 0.2.1
-------------

Unreleased

Fix

- Schema: update ExtraFieldsSchema handles fields declared with ``data_key``

Version 0.2.0
-------------

Released on June 1st 2018

Feature

- implement default config path

Version 0.1.3
-------------

Released on May 30th 2018

Docs

- setup readthedocs

Version 0.1.2
-------------

Released on May 30th 2018

Docs

- fix badges in README

Version 0.1.1
-------------

Released on May 30th 2018

No Change

Version 0.1.0
-------------

Released on May 30th 2018

Features

- input data validation and automatic processing using `marshmallow`_
- substitution of environment variables in input data (following `docker compose variable substitution syntax`_)
- configuration loading from .yaml file

.. _`marshmallow`: https://github.com/marshmallow-code/marshmallow
.. _`docker compose variable substitution syntax`: https://docs.docker.com/compose/compose-file/#variable-substitution

Version 0.0.0
-------------

Unreleased

Chore

- Project: Initialize project